from pathlib import Path

from setuptools import setup, find_packages

from mypy_boto3.version import __version__ as version


ROOT_PATH = Path(__file__).parent

long_description = (ROOT_PATH / "README.md").read_text()

setup(
    name="mypy-boto3",
    version=version,
    packages=find_packages(),
    url="https://github.com/vemel/mypy_boto3",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Mypy-friendly boto3 type annotations master module.",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Typed",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_data={"mypy_boto3": ["py.typed"]},
    extras_require={
        "all": [
            "mypy-boto3-acm",
            "mypy-boto3-acm-pca",
            "mypy-boto3-alexaforbusiness",
            "mypy-boto3-amplify",
            "mypy-boto3-apigateway",
            "mypy-boto3-apigatewaymanagementapi",
            "mypy-boto3-apigatewayv2",
            "mypy-boto3-application-autoscaling",
            "mypy-boto3-application-insights",
            "mypy-boto3-appmesh",
            "mypy-boto3-appstream",
            "mypy-boto3-appsync",
            "mypy-boto3-athena",
            "mypy-boto3-autoscaling",
            "mypy-boto3-autoscaling-plans",
            "mypy-boto3-backup",
            "mypy-boto3-batch",
            "mypy-boto3-budgets",
            "mypy-boto3-ce",
            "mypy-boto3-chime",
            "mypy-boto3-cloud9",
            "mypy-boto3-clouddirectory",
            "mypy-boto3-cloudformation",
            "mypy-boto3-cloudfront",
            "mypy-boto3-cloudhsm",
            "mypy-boto3-cloudhsmv2",
            "mypy-boto3-cloudsearch",
            "mypy-boto3-cloudsearchdomain",
            "mypy-boto3-cloudtrail",
            "mypy-boto3-cloudwatch",
            "mypy-boto3-codebuild",
            "mypy-boto3-codecommit",
            "mypy-boto3-codedeploy",
            "mypy-boto3-codepipeline",
            "mypy-boto3-codestar",
            "mypy-boto3-codestar-notifications",
            "mypy-boto3-cognito-identity",
            "mypy-boto3-cognito-idp",
            "mypy-boto3-cognito-sync",
            "mypy-boto3-comprehend",
            "mypy-boto3-comprehendmedical",
            "mypy-boto3-config",
            "mypy-boto3-connect",
            "mypy-boto3-cur",
            "mypy-boto3-datapipeline",
            "mypy-boto3-datasync",
            "mypy-boto3-dax",
            "mypy-boto3-devicefarm",
            "mypy-boto3-directconnect",
            "mypy-boto3-discovery",
            "mypy-boto3-dlm",
            "mypy-boto3-dms",
            "mypy-boto3-docdb",
            "mypy-boto3-ds",
            "mypy-boto3-dynamodb",
            "mypy-boto3-dynamodbstreams",
            "mypy-boto3-ec2",
            "mypy-boto3-ec2-instance-connect",
            "mypy-boto3-ecr",
            "mypy-boto3-ecs",
            "mypy-boto3-efs",
            "mypy-boto3-eks",
            "mypy-boto3-elasticache",
            "mypy-boto3-elasticbeanstalk",
            "mypy-boto3-elastictranscoder",
            "mypy-boto3-elb",
            "mypy-boto3-elbv2",
            "mypy-boto3-emr",
            "mypy-boto3-es",
            "mypy-boto3-events",
            "mypy-boto3-firehose",
            "mypy-boto3-fms",
            "mypy-boto3-forecast",
            "mypy-boto3-forecastquery",
            "mypy-boto3-fsx",
            "mypy-boto3-gamelift",
            "mypy-boto3-glacier",
            "mypy-boto3-globalaccelerator",
            "mypy-boto3-glue",
            "mypy-boto3-greengrass",
            "mypy-boto3-groundstation",
            "mypy-boto3-guardduty",
            "mypy-boto3-health",
            "mypy-boto3-iam",
            "mypy-boto3-importexport",
            "mypy-boto3-inspector",
            "mypy-boto3-iot",
            "mypy-boto3-iot-data",
            "mypy-boto3-iot-jobs-data",
            "mypy-boto3-iot1click-devices",
            "mypy-boto3-iot1click-projects",
            "mypy-boto3-iotanalytics",
            "mypy-boto3-iotevents",
            "mypy-boto3-iotevents-data",
            "mypy-boto3-iotthingsgraph",
            "mypy-boto3-kafka",
            "mypy-boto3-kinesis",
            "mypy-boto3-kinesis-video-archived-media",
            "mypy-boto3-kinesis-video-media",
            "mypy-boto3-kinesisanalytics",
            "mypy-boto3-kinesisanalyticsv2",
            "mypy-boto3-kinesisvideo",
            "mypy-boto3-kms",
            "mypy-boto3-lakeformation",
            "mypy-boto3-lambda",
            "mypy-boto3-lex-models",
            "mypy-boto3-lex-runtime",
            "mypy-boto3-license-manager",
            "mypy-boto3-lightsail",
            "mypy-boto3-logs",
            "mypy-boto3-machinelearning",
            "mypy-boto3-macie",
            "mypy-boto3-managedblockchain",
            "mypy-boto3-marketplace-entitlement",
            "mypy-boto3-marketplacecommerceanalytics",
            "mypy-boto3-mediaconnect",
            "mypy-boto3-mediaconvert",
            "mypy-boto3-medialive",
            "mypy-boto3-mediapackage",
            "mypy-boto3-mediapackage-vod",
            "mypy-boto3-mediastore",
            "mypy-boto3-mediastore-data",
            "mypy-boto3-mediatailor",
            "mypy-boto3-meteringmarketplace",
            "mypy-boto3-mgh",
            "mypy-boto3-mobile",
            "mypy-boto3-mq",
            "mypy-boto3-mturk",
            "mypy-boto3-neptune",
            "mypy-boto3-opsworks",
            "mypy-boto3-opsworkscm",
            "mypy-boto3-organizations",
            "mypy-boto3-personalize",
            "mypy-boto3-personalize-events",
            "mypy-boto3-personalize-runtime",
            "mypy-boto3-pi",
            "mypy-boto3-pinpoint",
            "mypy-boto3-pinpoint-email",
            "mypy-boto3-pinpoint-sms-voice",
            "mypy-boto3-polly",
            "mypy-boto3-pricing",
            "mypy-boto3-qldb",
            "mypy-boto3-qldb-session",
            "mypy-boto3-quicksight",
            "mypy-boto3-ram",
            "mypy-boto3-rds",
            "mypy-boto3-rds-data",
            "mypy-boto3-redshift",
            "mypy-boto3-rekognition",
            "mypy-boto3-resource-groups",
            "mypy-boto3-resourcegroupstaggingapi",
            "mypy-boto3-robomaker",
            "mypy-boto3-route53",
            "mypy-boto3-route53domains",
            "mypy-boto3-route53resolver",
            "mypy-boto3-s3",
            "mypy-boto3-s3control",
            "mypy-boto3-sagemaker",
            "mypy-boto3-sagemaker-runtime",
            "mypy-boto3-savingsplans",
            "mypy-boto3-sdb",
            "mypy-boto3-secretsmanager",
            "mypy-boto3-securityhub",
            "mypy-boto3-serverlessrepo",
            "mypy-boto3-service-quotas",
            "mypy-boto3-servicecatalog",
            "mypy-boto3-servicediscovery",
            "mypy-boto3-ses",
            "mypy-boto3-shield",
            "mypy-boto3-signer",
            "mypy-boto3-sms",
            "mypy-boto3-sms-voice",
            "mypy-boto3-snowball",
            "mypy-boto3-sns",
            "mypy-boto3-sqs",
            "mypy-boto3-ssm",
            "mypy-boto3-stepfunctions",
            "mypy-boto3-storagegateway",
            "mypy-boto3-sts",
            "mypy-boto3-support",
            "mypy-boto3-swf",
            "mypy-boto3-textract",
            "mypy-boto3-transcribe",
            "mypy-boto3-transfer",
            "mypy-boto3-translate",
            "mypy-boto3-waf",
            "mypy-boto3-waf-regional",
            "mypy-boto3-workdocs",
            "mypy-boto3-worklink",
            "mypy-boto3-workmail",
            "mypy-boto3-workmailmessageflow",
            "mypy-boto3-workspaces",
            "mypy-boto3-xray",
        ],
        "all-with-docs": [
            "mypy-boto3-acm",
            "mypy-boto3-acm-pca",
            "mypy-boto3-alexaforbusiness",
            "mypy-boto3-amplify",
            "mypy-boto3-apigateway",
            "mypy-boto3-apigatewaymanagementapi",
            "mypy-boto3-apigatewayv2",
            "mypy-boto3-application-autoscaling",
            "mypy-boto3-application-insights",
            "mypy-boto3-appmesh",
            "mypy-boto3-appstream",
            "mypy-boto3-appsync",
            "mypy-boto3-athena",
            "mypy-boto3-autoscaling",
            "mypy-boto3-autoscaling-plans",
            "mypy-boto3-backup",
            "mypy-boto3-batch",
            "mypy-boto3-budgets",
            "mypy-boto3-ce",
            "mypy-boto3-chime",
            "mypy-boto3-cloud9",
            "mypy-boto3-clouddirectory",
            "mypy-boto3-cloudformation",
            "mypy-boto3-cloudfront",
            "mypy-boto3-cloudhsm",
            "mypy-boto3-cloudhsmv2",
            "mypy-boto3-cloudsearch",
            "mypy-boto3-cloudsearchdomain",
            "mypy-boto3-cloudtrail",
            "mypy-boto3-cloudwatch",
            "mypy-boto3-codebuild",
            "mypy-boto3-codecommit",
            "mypy-boto3-codedeploy",
            "mypy-boto3-codepipeline",
            "mypy-boto3-codestar",
            "mypy-boto3-codestar-notifications",
            "mypy-boto3-cognito-identity",
            "mypy-boto3-cognito-idp",
            "mypy-boto3-cognito-sync",
            "mypy-boto3-comprehend",
            "mypy-boto3-comprehendmedical",
            "mypy-boto3-config",
            "mypy-boto3-connect",
            "mypy-boto3-cur",
            "mypy-boto3-datapipeline",
            "mypy-boto3-datasync",
            "mypy-boto3-dax",
            "mypy-boto3-devicefarm",
            "mypy-boto3-directconnect",
            "mypy-boto3-discovery",
            "mypy-boto3-dlm",
            "mypy-boto3-dms",
            "mypy-boto3-docdb",
            "mypy-boto3-ds",
            "mypy-boto3-dynamodb",
            "mypy-boto3-dynamodbstreams",
            "mypy-boto3-ec2",
            "mypy-boto3-ec2-instance-connect",
            "mypy-boto3-ecr",
            "mypy-boto3-ecs",
            "mypy-boto3-efs",
            "mypy-boto3-eks",
            "mypy-boto3-elasticache",
            "mypy-boto3-elasticbeanstalk",
            "mypy-boto3-elastictranscoder",
            "mypy-boto3-elb",
            "mypy-boto3-elbv2",
            "mypy-boto3-emr",
            "mypy-boto3-es",
            "mypy-boto3-events",
            "mypy-boto3-firehose",
            "mypy-boto3-fms",
            "mypy-boto3-forecast",
            "mypy-boto3-forecastquery",
            "mypy-boto3-fsx",
            "mypy-boto3-gamelift",
            "mypy-boto3-glacier",
            "mypy-boto3-globalaccelerator",
            "mypy-boto3-glue",
            "mypy-boto3-greengrass",
            "mypy-boto3-groundstation",
            "mypy-boto3-guardduty",
            "mypy-boto3-health",
            "mypy-boto3-iam",
            "mypy-boto3-importexport",
            "mypy-boto3-inspector",
            "mypy-boto3-iot",
            "mypy-boto3-iot-data",
            "mypy-boto3-iot-jobs-data",
            "mypy-boto3-iot1click-devices",
            "mypy-boto3-iot1click-projects",
            "mypy-boto3-iotanalytics",
            "mypy-boto3-iotevents",
            "mypy-boto3-iotevents-data",
            "mypy-boto3-iotthingsgraph",
            "mypy-boto3-kafka",
            "mypy-boto3-kinesis",
            "mypy-boto3-kinesis-video-archived-media",
            "mypy-boto3-kinesis-video-media",
            "mypy-boto3-kinesisanalytics",
            "mypy-boto3-kinesisanalyticsv2",
            "mypy-boto3-kinesisvideo",
            "mypy-boto3-kms",
            "mypy-boto3-lakeformation",
            "mypy-boto3-lambda",
            "mypy-boto3-lex-models",
            "mypy-boto3-lex-runtime",
            "mypy-boto3-license-manager",
            "mypy-boto3-lightsail",
            "mypy-boto3-logs",
            "mypy-boto3-machinelearning",
            "mypy-boto3-macie",
            "mypy-boto3-managedblockchain",
            "mypy-boto3-marketplace-entitlement",
            "mypy-boto3-marketplacecommerceanalytics",
            "mypy-boto3-mediaconnect",
            "mypy-boto3-mediaconvert",
            "mypy-boto3-medialive",
            "mypy-boto3-mediapackage",
            "mypy-boto3-mediapackage-vod",
            "mypy-boto3-mediastore",
            "mypy-boto3-mediastore-data",
            "mypy-boto3-mediatailor",
            "mypy-boto3-meteringmarketplace",
            "mypy-boto3-mgh",
            "mypy-boto3-mobile",
            "mypy-boto3-mq",
            "mypy-boto3-mturk",
            "mypy-boto3-neptune",
            "mypy-boto3-opsworks",
            "mypy-boto3-opsworkscm",
            "mypy-boto3-organizations",
            "mypy-boto3-personalize",
            "mypy-boto3-personalize-events",
            "mypy-boto3-personalize-runtime",
            "mypy-boto3-pi",
            "mypy-boto3-pinpoint",
            "mypy-boto3-pinpoint-email",
            "mypy-boto3-pinpoint-sms-voice",
            "mypy-boto3-polly",
            "mypy-boto3-pricing",
            "mypy-boto3-qldb",
            "mypy-boto3-qldb-session",
            "mypy-boto3-quicksight",
            "mypy-boto3-ram",
            "mypy-boto3-rds",
            "mypy-boto3-rds-data",
            "mypy-boto3-redshift",
            "mypy-boto3-rekognition",
            "mypy-boto3-resource-groups",
            "mypy-boto3-resourcegroupstaggingapi",
            "mypy-boto3-robomaker",
            "mypy-boto3-route53",
            "mypy-boto3-route53domains",
            "mypy-boto3-route53resolver",
            "mypy-boto3-s3",
            "mypy-boto3-s3control",
            "mypy-boto3-sagemaker",
            "mypy-boto3-sagemaker-runtime",
            "mypy-boto3-savingsplans",
            "mypy-boto3-sdb",
            "mypy-boto3-secretsmanager",
            "mypy-boto3-securityhub",
            "mypy-boto3-serverlessrepo",
            "mypy-boto3-service-quotas",
            "mypy-boto3-servicecatalog",
            "mypy-boto3-servicediscovery",
            "mypy-boto3-ses",
            "mypy-boto3-shield",
            "mypy-boto3-signer",
            "mypy-boto3-sms",
            "mypy-boto3-sms-voice",
            "mypy-boto3-snowball",
            "mypy-boto3-sns",
            "mypy-boto3-sqs",
            "mypy-boto3-ssm",
            "mypy-boto3-stepfunctions",
            "mypy-boto3-storagegateway",
            "mypy-boto3-sts",
            "mypy-boto3-support",
            "mypy-boto3-swf",
            "mypy-boto3-textract",
            "mypy-boto3-transcribe",
            "mypy-boto3-transfer",
            "mypy-boto3-translate",
            "mypy-boto3-waf",
            "mypy-boto3-waf-regional",
            "mypy-boto3-workdocs",
            "mypy-boto3-worklink",
            "mypy-boto3-workmail",
            "mypy-boto3-workmailmessageflow",
            "mypy-boto3-workspaces",
            "mypy-boto3-xray",
        ],
        "acm": ["mypy-boto3-acm"],
        "acm-with-docs": ["mypy-boto3-acm"],
        "acm-pca": ["mypy-boto3-acm-pca"],
        "acm-pca-with-docs": ["mypy-boto3-acm-pca"],
        "alexaforbusiness": ["mypy-boto3-alexaforbusiness"],
        "alexaforbusiness-with-docs": ["mypy-boto3-alexaforbusiness"],
        "amplify": ["mypy-boto3-amplify"],
        "amplify-with-docs": ["mypy-boto3-amplify"],
        "apigateway": ["mypy-boto3-apigateway"],
        "apigateway-with-docs": ["mypy-boto3-apigateway"],
        "apigatewaymanagementapi": ["mypy-boto3-apigatewaymanagementapi"],
        "apigatewaymanagementapi-with-docs": ["mypy-boto3-apigatewaymanagementapi"],
        "apigatewayv2": ["mypy-boto3-apigatewayv2"],
        "apigatewayv2-with-docs": ["mypy-boto3-apigatewayv2"],
        "application-autoscaling": ["mypy-boto3-application-autoscaling"],
        "application-autoscaling-with-docs": ["mypy-boto3-application-autoscaling"],
        "application-insights": ["mypy-boto3-application-insights"],
        "application-insights-with-docs": ["mypy-boto3-application-insights"],
        "appmesh": ["mypy-boto3-appmesh"],
        "appmesh-with-docs": ["mypy-boto3-appmesh"],
        "appstream": ["mypy-boto3-appstream"],
        "appstream-with-docs": ["mypy-boto3-appstream"],
        "appsync": ["mypy-boto3-appsync"],
        "appsync-with-docs": ["mypy-boto3-appsync"],
        "athena": ["mypy-boto3-athena"],
        "athena-with-docs": ["mypy-boto3-athena"],
        "autoscaling": ["mypy-boto3-autoscaling"],
        "autoscaling-with-docs": ["mypy-boto3-autoscaling"],
        "autoscaling-plans": ["mypy-boto3-autoscaling-plans"],
        "autoscaling-plans-with-docs": ["mypy-boto3-autoscaling-plans"],
        "backup": ["mypy-boto3-backup"],
        "backup-with-docs": ["mypy-boto3-backup"],
        "batch": ["mypy-boto3-batch"],
        "batch-with-docs": ["mypy-boto3-batch"],
        "budgets": ["mypy-boto3-budgets"],
        "budgets-with-docs": ["mypy-boto3-budgets"],
        "ce": ["mypy-boto3-ce"],
        "ce-with-docs": ["mypy-boto3-ce"],
        "chime": ["mypy-boto3-chime"],
        "chime-with-docs": ["mypy-boto3-chime"],
        "cloud9": ["mypy-boto3-cloud9"],
        "cloud9-with-docs": ["mypy-boto3-cloud9"],
        "clouddirectory": ["mypy-boto3-clouddirectory"],
        "clouddirectory-with-docs": ["mypy-boto3-clouddirectory"],
        "cloudformation": ["mypy-boto3-cloudformation"],
        "cloudformation-with-docs": ["mypy-boto3-cloudformation"],
        "cloudfront": ["mypy-boto3-cloudfront"],
        "cloudfront-with-docs": ["mypy-boto3-cloudfront"],
        "cloudhsm": ["mypy-boto3-cloudhsm"],
        "cloudhsm-with-docs": ["mypy-boto3-cloudhsm"],
        "cloudhsmv2": ["mypy-boto3-cloudhsmv2"],
        "cloudhsmv2-with-docs": ["mypy-boto3-cloudhsmv2"],
        "cloudsearch": ["mypy-boto3-cloudsearch"],
        "cloudsearch-with-docs": ["mypy-boto3-cloudsearch"],
        "cloudsearchdomain": ["mypy-boto3-cloudsearchdomain"],
        "cloudsearchdomain-with-docs": ["mypy-boto3-cloudsearchdomain"],
        "cloudtrail": ["mypy-boto3-cloudtrail"],
        "cloudtrail-with-docs": ["mypy-boto3-cloudtrail"],
        "cloudwatch": ["mypy-boto3-cloudwatch"],
        "cloudwatch-with-docs": ["mypy-boto3-cloudwatch"],
        "codebuild": ["mypy-boto3-codebuild"],
        "codebuild-with-docs": ["mypy-boto3-codebuild"],
        "codecommit": ["mypy-boto3-codecommit"],
        "codecommit-with-docs": ["mypy-boto3-codecommit"],
        "codedeploy": ["mypy-boto3-codedeploy"],
        "codedeploy-with-docs": ["mypy-boto3-codedeploy"],
        "codepipeline": ["mypy-boto3-codepipeline"],
        "codepipeline-with-docs": ["mypy-boto3-codepipeline"],
        "codestar": ["mypy-boto3-codestar"],
        "codestar-with-docs": ["mypy-boto3-codestar"],
        "codestar-notifications": ["mypy-boto3-codestar-notifications"],
        "codestar-notifications-with-docs": ["mypy-boto3-codestar-notifications"],
        "cognito-identity": ["mypy-boto3-cognito-identity"],
        "cognito-identity-with-docs": ["mypy-boto3-cognito-identity"],
        "cognito-idp": ["mypy-boto3-cognito-idp"],
        "cognito-idp-with-docs": ["mypy-boto3-cognito-idp"],
        "cognito-sync": ["mypy-boto3-cognito-sync"],
        "cognito-sync-with-docs": ["mypy-boto3-cognito-sync"],
        "comprehend": ["mypy-boto3-comprehend"],
        "comprehend-with-docs": ["mypy-boto3-comprehend"],
        "comprehendmedical": ["mypy-boto3-comprehendmedical"],
        "comprehendmedical-with-docs": ["mypy-boto3-comprehendmedical"],
        "config": ["mypy-boto3-config"],
        "config-with-docs": ["mypy-boto3-config"],
        "connect": ["mypy-boto3-connect"],
        "connect-with-docs": ["mypy-boto3-connect"],
        "cur": ["mypy-boto3-cur"],
        "cur-with-docs": ["mypy-boto3-cur"],
        "datapipeline": ["mypy-boto3-datapipeline"],
        "datapipeline-with-docs": ["mypy-boto3-datapipeline"],
        "datasync": ["mypy-boto3-datasync"],
        "datasync-with-docs": ["mypy-boto3-datasync"],
        "dax": ["mypy-boto3-dax"],
        "dax-with-docs": ["mypy-boto3-dax"],
        "devicefarm": ["mypy-boto3-devicefarm"],
        "devicefarm-with-docs": ["mypy-boto3-devicefarm"],
        "directconnect": ["mypy-boto3-directconnect"],
        "directconnect-with-docs": ["mypy-boto3-directconnect"],
        "discovery": ["mypy-boto3-discovery"],
        "discovery-with-docs": ["mypy-boto3-discovery"],
        "dlm": ["mypy-boto3-dlm"],
        "dlm-with-docs": ["mypy-boto3-dlm"],
        "dms": ["mypy-boto3-dms"],
        "dms-with-docs": ["mypy-boto3-dms"],
        "docdb": ["mypy-boto3-docdb"],
        "docdb-with-docs": ["mypy-boto3-docdb"],
        "ds": ["mypy-boto3-ds"],
        "ds-with-docs": ["mypy-boto3-ds"],
        "dynamodb": ["mypy-boto3-dynamodb"],
        "dynamodb-with-docs": ["mypy-boto3-dynamodb"],
        "dynamodbstreams": ["mypy-boto3-dynamodbstreams"],
        "dynamodbstreams-with-docs": ["mypy-boto3-dynamodbstreams"],
        "ec2": ["mypy-boto3-ec2"],
        "ec2-with-docs": ["mypy-boto3-ec2"],
        "ec2-instance-connect": ["mypy-boto3-ec2-instance-connect"],
        "ec2-instance-connect-with-docs": ["mypy-boto3-ec2-instance-connect"],
        "ecr": ["mypy-boto3-ecr"],
        "ecr-with-docs": ["mypy-boto3-ecr"],
        "ecs": ["mypy-boto3-ecs"],
        "ecs-with-docs": ["mypy-boto3-ecs"],
        "efs": ["mypy-boto3-efs"],
        "efs-with-docs": ["mypy-boto3-efs"],
        "eks": ["mypy-boto3-eks"],
        "eks-with-docs": ["mypy-boto3-eks"],
        "elasticache": ["mypy-boto3-elasticache"],
        "elasticache-with-docs": ["mypy-boto3-elasticache"],
        "elasticbeanstalk": ["mypy-boto3-elasticbeanstalk"],
        "elasticbeanstalk-with-docs": ["mypy-boto3-elasticbeanstalk"],
        "elastictranscoder": ["mypy-boto3-elastictranscoder"],
        "elastictranscoder-with-docs": ["mypy-boto3-elastictranscoder"],
        "elb": ["mypy-boto3-elb"],
        "elb-with-docs": ["mypy-boto3-elb"],
        "elbv2": ["mypy-boto3-elbv2"],
        "elbv2-with-docs": ["mypy-boto3-elbv2"],
        "emr": ["mypy-boto3-emr"],
        "emr-with-docs": ["mypy-boto3-emr"],
        "es": ["mypy-boto3-es"],
        "es-with-docs": ["mypy-boto3-es"],
        "events": ["mypy-boto3-events"],
        "events-with-docs": ["mypy-boto3-events"],
        "firehose": ["mypy-boto3-firehose"],
        "firehose-with-docs": ["mypy-boto3-firehose"],
        "fms": ["mypy-boto3-fms"],
        "fms-with-docs": ["mypy-boto3-fms"],
        "forecast": ["mypy-boto3-forecast"],
        "forecast-with-docs": ["mypy-boto3-forecast"],
        "forecastquery": ["mypy-boto3-forecastquery"],
        "forecastquery-with-docs": ["mypy-boto3-forecastquery"],
        "fsx": ["mypy-boto3-fsx"],
        "fsx-with-docs": ["mypy-boto3-fsx"],
        "gamelift": ["mypy-boto3-gamelift"],
        "gamelift-with-docs": ["mypy-boto3-gamelift"],
        "glacier": ["mypy-boto3-glacier"],
        "glacier-with-docs": ["mypy-boto3-glacier"],
        "globalaccelerator": ["mypy-boto3-globalaccelerator"],
        "globalaccelerator-with-docs": ["mypy-boto3-globalaccelerator"],
        "glue": ["mypy-boto3-glue"],
        "glue-with-docs": ["mypy-boto3-glue"],
        "greengrass": ["mypy-boto3-greengrass"],
        "greengrass-with-docs": ["mypy-boto3-greengrass"],
        "groundstation": ["mypy-boto3-groundstation"],
        "groundstation-with-docs": ["mypy-boto3-groundstation"],
        "guardduty": ["mypy-boto3-guardduty"],
        "guardduty-with-docs": ["mypy-boto3-guardduty"],
        "health": ["mypy-boto3-health"],
        "health-with-docs": ["mypy-boto3-health"],
        "iam": ["mypy-boto3-iam"],
        "iam-with-docs": ["mypy-boto3-iam"],
        "importexport": ["mypy-boto3-importexport"],
        "importexport-with-docs": ["mypy-boto3-importexport"],
        "inspector": ["mypy-boto3-inspector"],
        "inspector-with-docs": ["mypy-boto3-inspector"],
        "iot": ["mypy-boto3-iot"],
        "iot-with-docs": ["mypy-boto3-iot"],
        "iot-data": ["mypy-boto3-iot-data"],
        "iot-data-with-docs": ["mypy-boto3-iot-data"],
        "iot-jobs-data": ["mypy-boto3-iot-jobs-data"],
        "iot-jobs-data-with-docs": ["mypy-boto3-iot-jobs-data"],
        "iot1click-devices": ["mypy-boto3-iot1click-devices"],
        "iot1click-devices-with-docs": ["mypy-boto3-iot1click-devices"],
        "iot1click-projects": ["mypy-boto3-iot1click-projects"],
        "iot1click-projects-with-docs": ["mypy-boto3-iot1click-projects"],
        "iotanalytics": ["mypy-boto3-iotanalytics"],
        "iotanalytics-with-docs": ["mypy-boto3-iotanalytics"],
        "iotevents": ["mypy-boto3-iotevents"],
        "iotevents-with-docs": ["mypy-boto3-iotevents"],
        "iotevents-data": ["mypy-boto3-iotevents-data"],
        "iotevents-data-with-docs": ["mypy-boto3-iotevents-data"],
        "iotthingsgraph": ["mypy-boto3-iotthingsgraph"],
        "iotthingsgraph-with-docs": ["mypy-boto3-iotthingsgraph"],
        "kafka": ["mypy-boto3-kafka"],
        "kafka-with-docs": ["mypy-boto3-kafka"],
        "kinesis": ["mypy-boto3-kinesis"],
        "kinesis-with-docs": ["mypy-boto3-kinesis"],
        "kinesis-video-archived-media": ["mypy-boto3-kinesis-video-archived-media"],
        "kinesis-video-archived-media-with-docs": [
            "mypy-boto3-kinesis-video-archived-media"
        ],
        "kinesis-video-media": ["mypy-boto3-kinesis-video-media"],
        "kinesis-video-media-with-docs": ["mypy-boto3-kinesis-video-media"],
        "kinesisanalytics": ["mypy-boto3-kinesisanalytics"],
        "kinesisanalytics-with-docs": ["mypy-boto3-kinesisanalytics"],
        "kinesisanalyticsv2": ["mypy-boto3-kinesisanalyticsv2"],
        "kinesisanalyticsv2-with-docs": ["mypy-boto3-kinesisanalyticsv2"],
        "kinesisvideo": ["mypy-boto3-kinesisvideo"],
        "kinesisvideo-with-docs": ["mypy-boto3-kinesisvideo"],
        "kms": ["mypy-boto3-kms"],
        "kms-with-docs": ["mypy-boto3-kms"],
        "lakeformation": ["mypy-boto3-lakeformation"],
        "lakeformation-with-docs": ["mypy-boto3-lakeformation"],
        "lambda": ["mypy-boto3-lambda"],
        "lambda-with-docs": ["mypy-boto3-lambda"],
        "lex-models": ["mypy-boto3-lex-models"],
        "lex-models-with-docs": ["mypy-boto3-lex-models"],
        "lex-runtime": ["mypy-boto3-lex-runtime"],
        "lex-runtime-with-docs": ["mypy-boto3-lex-runtime"],
        "license-manager": ["mypy-boto3-license-manager"],
        "license-manager-with-docs": ["mypy-boto3-license-manager"],
        "lightsail": ["mypy-boto3-lightsail"],
        "lightsail-with-docs": ["mypy-boto3-lightsail"],
        "logs": ["mypy-boto3-logs"],
        "logs-with-docs": ["mypy-boto3-logs"],
        "machinelearning": ["mypy-boto3-machinelearning"],
        "machinelearning-with-docs": ["mypy-boto3-machinelearning"],
        "macie": ["mypy-boto3-macie"],
        "macie-with-docs": ["mypy-boto3-macie"],
        "managedblockchain": ["mypy-boto3-managedblockchain"],
        "managedblockchain-with-docs": ["mypy-boto3-managedblockchain"],
        "marketplace-entitlement": ["mypy-boto3-marketplace-entitlement"],
        "marketplace-entitlement-with-docs": ["mypy-boto3-marketplace-entitlement"],
        "marketplacecommerceanalytics": ["mypy-boto3-marketplacecommerceanalytics"],
        "marketplacecommerceanalytics-with-docs": [
            "mypy-boto3-marketplacecommerceanalytics"
        ],
        "mediaconnect": ["mypy-boto3-mediaconnect"],
        "mediaconnect-with-docs": ["mypy-boto3-mediaconnect"],
        "mediaconvert": ["mypy-boto3-mediaconvert"],
        "mediaconvert-with-docs": ["mypy-boto3-mediaconvert"],
        "medialive": ["mypy-boto3-medialive"],
        "medialive-with-docs": ["mypy-boto3-medialive"],
        "mediapackage": ["mypy-boto3-mediapackage"],
        "mediapackage-with-docs": ["mypy-boto3-mediapackage"],
        "mediapackage-vod": ["mypy-boto3-mediapackage-vod"],
        "mediapackage-vod-with-docs": ["mypy-boto3-mediapackage-vod"],
        "mediastore": ["mypy-boto3-mediastore"],
        "mediastore-with-docs": ["mypy-boto3-mediastore"],
        "mediastore-data": ["mypy-boto3-mediastore-data"],
        "mediastore-data-with-docs": ["mypy-boto3-mediastore-data"],
        "mediatailor": ["mypy-boto3-mediatailor"],
        "mediatailor-with-docs": ["mypy-boto3-mediatailor"],
        "meteringmarketplace": ["mypy-boto3-meteringmarketplace"],
        "meteringmarketplace-with-docs": ["mypy-boto3-meteringmarketplace"],
        "mgh": ["mypy-boto3-mgh"],
        "mgh-with-docs": ["mypy-boto3-mgh"],
        "mobile": ["mypy-boto3-mobile"],
        "mobile-with-docs": ["mypy-boto3-mobile"],
        "mq": ["mypy-boto3-mq"],
        "mq-with-docs": ["mypy-boto3-mq"],
        "mturk": ["mypy-boto3-mturk"],
        "mturk-with-docs": ["mypy-boto3-mturk"],
        "neptune": ["mypy-boto3-neptune"],
        "neptune-with-docs": ["mypy-boto3-neptune"],
        "opsworks": ["mypy-boto3-opsworks"],
        "opsworks-with-docs": ["mypy-boto3-opsworks"],
        "opsworkscm": ["mypy-boto3-opsworkscm"],
        "opsworkscm-with-docs": ["mypy-boto3-opsworkscm"],
        "organizations": ["mypy-boto3-organizations"],
        "organizations-with-docs": ["mypy-boto3-organizations"],
        "personalize": ["mypy-boto3-personalize"],
        "personalize-with-docs": ["mypy-boto3-personalize"],
        "personalize-events": ["mypy-boto3-personalize-events"],
        "personalize-events-with-docs": ["mypy-boto3-personalize-events"],
        "personalize-runtime": ["mypy-boto3-personalize-runtime"],
        "personalize-runtime-with-docs": ["mypy-boto3-personalize-runtime"],
        "pi": ["mypy-boto3-pi"],
        "pi-with-docs": ["mypy-boto3-pi"],
        "pinpoint": ["mypy-boto3-pinpoint"],
        "pinpoint-with-docs": ["mypy-boto3-pinpoint"],
        "pinpoint-email": ["mypy-boto3-pinpoint-email"],
        "pinpoint-email-with-docs": ["mypy-boto3-pinpoint-email"],
        "pinpoint-sms-voice": ["mypy-boto3-pinpoint-sms-voice"],
        "pinpoint-sms-voice-with-docs": ["mypy-boto3-pinpoint-sms-voice"],
        "polly": ["mypy-boto3-polly"],
        "polly-with-docs": ["mypy-boto3-polly"],
        "pricing": ["mypy-boto3-pricing"],
        "pricing-with-docs": ["mypy-boto3-pricing"],
        "qldb": ["mypy-boto3-qldb"],
        "qldb-with-docs": ["mypy-boto3-qldb"],
        "qldb-session": ["mypy-boto3-qldb-session"],
        "qldb-session-with-docs": ["mypy-boto3-qldb-session"],
        "quicksight": ["mypy-boto3-quicksight"],
        "quicksight-with-docs": ["mypy-boto3-quicksight"],
        "ram": ["mypy-boto3-ram"],
        "ram-with-docs": ["mypy-boto3-ram"],
        "rds": ["mypy-boto3-rds"],
        "rds-with-docs": ["mypy-boto3-rds"],
        "rds-data": ["mypy-boto3-rds-data"],
        "rds-data-with-docs": ["mypy-boto3-rds-data"],
        "redshift": ["mypy-boto3-redshift"],
        "redshift-with-docs": ["mypy-boto3-redshift"],
        "rekognition": ["mypy-boto3-rekognition"],
        "rekognition-with-docs": ["mypy-boto3-rekognition"],
        "resource-groups": ["mypy-boto3-resource-groups"],
        "resource-groups-with-docs": ["mypy-boto3-resource-groups"],
        "resourcegroupstaggingapi": ["mypy-boto3-resourcegroupstaggingapi"],
        "resourcegroupstaggingapi-with-docs": ["mypy-boto3-resourcegroupstaggingapi"],
        "robomaker": ["mypy-boto3-robomaker"],
        "robomaker-with-docs": ["mypy-boto3-robomaker"],
        "route53": ["mypy-boto3-route53"],
        "route53-with-docs": ["mypy-boto3-route53"],
        "route53domains": ["mypy-boto3-route53domains"],
        "route53domains-with-docs": ["mypy-boto3-route53domains"],
        "route53resolver": ["mypy-boto3-route53resolver"],
        "route53resolver-with-docs": ["mypy-boto3-route53resolver"],
        "s3": ["mypy-boto3-s3"],
        "s3-with-docs": ["mypy-boto3-s3"],
        "s3control": ["mypy-boto3-s3control"],
        "s3control-with-docs": ["mypy-boto3-s3control"],
        "sagemaker": ["mypy-boto3-sagemaker"],
        "sagemaker-with-docs": ["mypy-boto3-sagemaker"],
        "sagemaker-runtime": ["mypy-boto3-sagemaker-runtime"],
        "sagemaker-runtime-with-docs": ["mypy-boto3-sagemaker-runtime"],
        "savingsplans": ["mypy-boto3-savingsplans"],
        "savingsplans-with-docs": ["mypy-boto3-savingsplans"],
        "sdb": ["mypy-boto3-sdb"],
        "sdb-with-docs": ["mypy-boto3-sdb"],
        "secretsmanager": ["mypy-boto3-secretsmanager"],
        "secretsmanager-with-docs": ["mypy-boto3-secretsmanager"],
        "securityhub": ["mypy-boto3-securityhub"],
        "securityhub-with-docs": ["mypy-boto3-securityhub"],
        "serverlessrepo": ["mypy-boto3-serverlessrepo"],
        "serverlessrepo-with-docs": ["mypy-boto3-serverlessrepo"],
        "service-quotas": ["mypy-boto3-service-quotas"],
        "service-quotas-with-docs": ["mypy-boto3-service-quotas"],
        "servicecatalog": ["mypy-boto3-servicecatalog"],
        "servicecatalog-with-docs": ["mypy-boto3-servicecatalog"],
        "servicediscovery": ["mypy-boto3-servicediscovery"],
        "servicediscovery-with-docs": ["mypy-boto3-servicediscovery"],
        "ses": ["mypy-boto3-ses"],
        "ses-with-docs": ["mypy-boto3-ses"],
        "shield": ["mypy-boto3-shield"],
        "shield-with-docs": ["mypy-boto3-shield"],
        "signer": ["mypy-boto3-signer"],
        "signer-with-docs": ["mypy-boto3-signer"],
        "sms": ["mypy-boto3-sms"],
        "sms-with-docs": ["mypy-boto3-sms"],
        "sms-voice": ["mypy-boto3-sms-voice"],
        "sms-voice-with-docs": ["mypy-boto3-sms-voice"],
        "snowball": ["mypy-boto3-snowball"],
        "snowball-with-docs": ["mypy-boto3-snowball"],
        "sns": ["mypy-boto3-sns"],
        "sns-with-docs": ["mypy-boto3-sns"],
        "sqs": ["mypy-boto3-sqs"],
        "sqs-with-docs": ["mypy-boto3-sqs"],
        "ssm": ["mypy-boto3-ssm"],
        "ssm-with-docs": ["mypy-boto3-ssm"],
        "stepfunctions": ["mypy-boto3-stepfunctions"],
        "stepfunctions-with-docs": ["mypy-boto3-stepfunctions"],
        "storagegateway": ["mypy-boto3-storagegateway"],
        "storagegateway-with-docs": ["mypy-boto3-storagegateway"],
        "sts": ["mypy-boto3-sts"],
        "sts-with-docs": ["mypy-boto3-sts"],
        "support": ["mypy-boto3-support"],
        "support-with-docs": ["mypy-boto3-support"],
        "swf": ["mypy-boto3-swf"],
        "swf-with-docs": ["mypy-boto3-swf"],
        "textract": ["mypy-boto3-textract"],
        "textract-with-docs": ["mypy-boto3-textract"],
        "transcribe": ["mypy-boto3-transcribe"],
        "transcribe-with-docs": ["mypy-boto3-transcribe"],
        "transfer": ["mypy-boto3-transfer"],
        "transfer-with-docs": ["mypy-boto3-transfer"],
        "translate": ["mypy-boto3-translate"],
        "translate-with-docs": ["mypy-boto3-translate"],
        "waf": ["mypy-boto3-waf"],
        "waf-with-docs": ["mypy-boto3-waf"],
        "waf-regional": ["mypy-boto3-waf-regional"],
        "waf-regional-with-docs": ["mypy-boto3-waf-regional"],
        "workdocs": ["mypy-boto3-workdocs"],
        "workdocs-with-docs": ["mypy-boto3-workdocs"],
        "worklink": ["mypy-boto3-worklink"],
        "worklink-with-docs": ["mypy-boto3-worklink"],
        "workmail": ["mypy-boto3-workmail"],
        "workmail-with-docs": ["mypy-boto3-workmail"],
        "workmailmessageflow": ["mypy-boto3-workmailmessageflow"],
        "workmailmessageflow-with-docs": ["mypy-boto3-workmailmessageflow"],
        "workspaces": ["mypy-boto3-workspaces"],
        "workspaces-with-docs": ["mypy-boto3-workspaces"],
        "xray": ["mypy-boto3-xray"],
        "xray-with-docs": ["mypy-boto3-xray"],
    },
    zip_safe=False,
)
